Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(668)

Unified Diff: src/objects.h

Issue 385035: Restore info needed to register profile ticks in functions from... (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: Created 11 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/handles.cc ('k') | src/objects-debug.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/objects.h
===================================================================
--- src/objects.h (revision 3266)
+++ src/objects.h (working copy)
@@ -3156,9 +3156,12 @@
// [compilation]: how the the script was compiled.
DECL_ACCESSORS(compilation_type, Smi)
- // [line_ends]: array of line ends positions.
- DECL_ACCESSORS(line_ends, Object)
+ // [line_ends]: FixedArray of line ends positions.
+ DECL_ACCESSORS(line_ends_fixed_array, Object)
+ // [line_ends]: JSArray of line ends positions.
+ DECL_ACCESSORS(line_ends_js_array, Object)
+
// [eval_from_function]: for eval scripts the funcion from which eval was
// called.
DECL_ACCESSORS(eval_from_function, Object)
@@ -3187,8 +3190,11 @@
static const int kWrapperOffset = kContextOffset + kPointerSize;
static const int kTypeOffset = kWrapperOffset + kPointerSize;
static const int kCompilationTypeOffset = kTypeOffset + kPointerSize;
- static const int kLineEndsOffset = kCompilationTypeOffset + kPointerSize;
- static const int kIdOffset = kLineEndsOffset + kPointerSize;
+ static const int kLineEndsFixedArrayOffset =
+ kCompilationTypeOffset + kPointerSize;
+ static const int kLineEndsJSArrayOffset =
+ kLineEndsFixedArrayOffset + kPointerSize;
+ static const int kIdOffset = kLineEndsJSArrayOffset + kPointerSize;
static const int kEvalFromFunctionOffset = kIdOffset + kPointerSize;
static const int kEvalFrominstructionsOffsetOffset =
kEvalFromFunctionOffset + kPointerSize;
« no previous file with comments | « src/handles.cc ('k') | src/objects-debug.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698